/** @file

  A brief file description

  @section license License

  Licensed to the Apache Software Foundation (ASF) under one
  or more contributor license agreements.  See the NOTICE file
  distributed with this work for additional information
  regarding copyright ownership.  The ASF licenses this file
  to you under the Apache License, Version 2.0 (the
  "License"); you may not use this file except in compliance
  with the License.  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */

#ifndef LOG_COLLATION_ACCEPT_H
#define LOG_COLLATION_ACCEPT_H

#include "P_EventSystem.h"
#include "P_Net.h"
struct LogCollationAccept : public Continuation {
public:
  LogCollationAccept(int port);
  ~LogCollationAccept();

  int accept_event(int event, NetVConnection *net_vc);

private:
  int m_port;
  Action *m_accept_action;
  Event *m_pending_event;
};

typedef int (LogCollationAccept::*LogCollationAcceptHandler)(int, void *);

#endif /* LOG_COLLATION_ACCEPT_H */
